FlutterDeckAutoplayPlugin class

A plugin that adds autoplay functionality to the slide deck.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildControls(BuildContext context, FlutterDeckPluginMenuItemBuilder menuItemBuilder) List<Widget>
Builds the controls for the plugin.
override
dispose() → void
Disposes the plugin.
override
init(FlutterDeck flutterDeck) → void
Initializes the plugin.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(BuildContext context, Widget child) Widget
Wraps the child with the plugin's widget.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited