FlutterDeckFooter class
A widget that renders a footer for a slide. The footer can contain the slide number, the speaker's social handle or a custom widget.
To customize the footer style, use FlutterDeckFooterTheme.
Example:
FlutterDeckFooterTheme(
data: FlutterDeckFooterThemeData(
slideNumberColor: Colors.white,
slideNumberTextStyle: FlutterDeckTheme.of(context).textTheme.bodySmall,
socialHandleColor: Colors.white,
socialHandleTextStyle:
FlutterDeckTheme.of(context).textTheme.bodyMedium,
),
child: FlutterDeckFooter.fromConfiguration(
configuration: const FlutterDeckFooterConfiguration(),
),
);
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlutterDeckFooter
- Available extensions
Constructors
-
Creates a widget that renders a footer for a slide.
const
- Creates a widget that renders a footer for a slide from a configuration. The configuration is used to determine whether to show the slide number, the social handle or a custom widget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showSlideNumber → bool
-
Whether to show the slide number in the footer.
final
- showSocialHandle → bool
-
Whether to show the speaker's social handle in the footer.
final
- widget → Widget?
-
A custom widget to show in the footer (overrides the social handle).
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withSlideConfiguration(
FlutterDeckSlideConfiguration configuration) → FlutterDeckSlideWidget -
Available on Widget, provided by the FlutterDeckSlideWidgetX extension
Returns a FlutterDeckSlideWidget with the givenconfiguration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited