FlutterDeckFooter constructor

const FlutterDeckFooter({
  1. bool showSlideNumber = false,
  2. bool showSocialHandle = false,
  3. Widget? widget,
  4. Key? key,
})

Creates a widget that renders a footer for a slide.

If showSlideNumber is true, the slide number will be rendered. By default, it is false.

If showSocialHandle is true, the speaker's social handle will be rendered. By default, it is false. If widget is also provided, widget will be rendered instead.

if widget is not null, it will be rendered. By default, it is null.

Implementation

const FlutterDeckFooter({this.showSlideNumber = false, this.showSocialHandle = false, this.widget, super.key});