flutter_deck library
The power of Flutter, in your presentations.
Classes
- FlutterDeck
- The main class used to interact with the slide deck.
- FlutterDeckApp
- The main widget of a slide deck.
- FlutterDeckAspectRatio
- The aspect ratio of the deck.
- FlutterDeckAutoplayNotifier
- The ChangeNotifier used to control the autoplay of the slide deck.
- FlutterDeckAutoplayPlugin
- A plugin that adds autoplay functionality to the slide deck.
- FlutterDeckAutoplayProvider
- A InheritedWidget that provides the FlutterDeckAutoplayNotifier to the widget tree.
- FlutterDeckBackground
- A widget that renders a background for a flutter deck slide.
- FlutterDeckBackgroundConfiguration
- The configuration for the slide deck background.
- FlutterDeckBigFactSlideTheme
-
An inherited widget that defines the visual properties of
FlutterDeckBigFactSlide. - FlutterDeckBigFactSlideThemeData
-
Defines the visual properties of
FlutterDeckBigFactSlide. - FlutterDeckBulletList
- A widget that renders a list of bullet points.
- FlutterDeckBulletListTheme
- An inherited widget that defines the visual properties of FlutterDeckBulletList.
- FlutterDeckBulletListThemeData
- Defines the visual properties of FlutterDeckBulletList.
- FlutterDeckCodeHighlight
- This widget provides syntax highlighting for many languages and animated line and code highlighting transitions.
- FlutterDeckCodeHighlightTheme
- An inherited widget that defines the visual properties of FlutterDeckCodeHighlight.
- FlutterDeckCodeHighlightThemeData
- Defines the visual properties of FlutterDeckCodeHighlight.
- FlutterDeckConfiguration
- The global configuration for the slide deck.
- FlutterDeckControlsConfiguration
- The configuration for the slide deck controls.
- A widget that renders a footer for a slide. The footer can contain the slide number, the speaker's social handle or a custom widget.
- The configuration for the slide deck footer.
- An inherited widget that defines the visual properties of FlutterDeckFooter.
- Defines the visual properties of FlutterDeckFooter.
- FlutterDeckGesturesConfiguration
- The configuration for the slide deck control gestures.
- FlutterDeckHeader
-
A widget that renders a header for a slide. The header can contain the slide
title. The title is rendered as an
AutoSizeTextwidget and is automatically resized to fit the available space. - FlutterDeckHeaderConfiguration
- The configuration for the slide deck header.
- FlutterDeckHeaderTheme
- An inherited widget that defines the visual properties of FlutterDeckHeader.
- FlutterDeckHeaderThemeData
- Defines the visual properties of FlutterDeckHeader.
- FlutterDeckImageSlideTheme
-
An inherited widget that defines the visual properties of
FlutterDeckImageSlide. - FlutterDeckImageSlideThemeData
-
Defines the visual properties of
FlutterDeckImageSlide. - FlutterDeckMarkerConfiguration
- The configuration for the slide deck marker.
- FlutterDeckPlugin
- A plugin for the FlutterDeck.
- FlutterDeckProgressIndicator
- A linear progress indicator that shows the current progress of the presentation.
- FlutterDeckProvider
- Provides the FlutterDeck to the widget tree.
- FlutterDeckQuoteSlideTheme
-
An inherited widget that defines the visual properties of
FlutterDeckQuoteSlide. - FlutterDeckQuoteSlideThemeData
-
Defines the visual properties of
FlutterDeckQuoteSlide. - FlutterDeckResolution
- The resolution of the deck.
-
FlutterDeckShortcut<
T extends Intent> - A shortcut for the slide deck.
- FlutterDeckShortcutsConfiguration
- The configuration for the slide deck keyboard shortcuts.
- FlutterDeckSlide
- The main widget for a slide in a slide deck.
- FlutterDeckSlideBase
- A base widget for a slide with a standard layout.
- FlutterDeckSlideConfiguration
- The configuration for a slide.
- FlutterDeckSlideImageRenderer
- A renderer that captures FlutterDeckSlides as images.
- FlutterDeckSlideSize
- The slide size of the deck.
- FlutterDeckSlideStepsBuilder
- A widget that builds a widget for a slide step. The widget is rebuilt when the slide step changes.
- FlutterDeckSlideStepsListener
- A widget that listens for changes to the slide step. The listener is called when the slide step changes.
- FlutterDeckSlideTheme
- An inherited widget that defines the base visual properties of FlutterDeckSlide.
- FlutterDeckSlideThemeData
- Defines the base visual properties of FlutterDeckSlide.
- FlutterDeckSlideWidget
- An abstract class that represents a slide in a slide deck.
- FlutterDeckSpeakerInfo
- Stores information about the speaker.
- FlutterDeckSpeakerInfoWidget
- A widget that displays the provided speaker info.
- FlutterDeckSpeakerInfoWidgetTheme
- An inherited widget that defines the visual properties of FlutterDeckSpeakerInfoWidget.
- FlutterDeckSpeakerInfoWidgetThemeData
- Defines the visual properties of FlutterDeckSpeakerInfoWidget.
- FlutterDeckSplitSlideTheme
-
An inherited widget that defines the visual properties of
FlutterDeckSplitSlide. - FlutterDeckSplitSlideThemeData
-
Defines the visual properties of
FlutterDeckSplitSlide. - FlutterDeckTemplateOverrideConfiguration
- The configuration for the slide deck template overrides.
- FlutterDeckTextTheme
- Defines the global text styles for a slide deck.
- FlutterDeckTheme
- An inherited widget that defines the visual properties of FlutterDeckTheme.
- FlutterDeckThemeData
- Defines the visual properties of a slide deck.
- FlutterDeckTitleSlideTheme
-
An inherited widget that defines the visual properties of
FlutterDeckTitleSlide. - FlutterDeckTitleSlideThemeData
-
Defines the visual properties of
FlutterDeckTitleSlide. - FlutterDeckTransition
- A transtion class used to define the transition between slides.
- FlutterDeckTransitionBuilder
- A builder for a transition between slides.
- SplitSlideRatio
-
A split ratio for a
FlutterDeckSplitSlide.
Extensions
- FlutterDeckSlideWidgetX on Widget
- FlutterDeckSlideWidget extension methods for the Widget class.
- FlutterDeckThemeX on BuildContext
- An extension on BuildContext that simplifies accessing the FlutterDeckTheme from the widget tree.
- FlutterDeckX on BuildContext
- An extension on BuildContext that simplifies accessing the FlutterDeck from the widget tree.
Typedefs
- FlutterDeckBigFactSlideBuilder = Widget Function(BuildContext context, String title, String? subtitle, WidgetBuilder? backgroundBuilder, WidgetBuilder? headerBuilder, int? subtitleMaxLines)
- A signature for a function that builds a big fact slide.
- FlutterDeckBlankSlideBuilder = Widget Function(BuildContext context, WidgetBuilder builder, WidgetBuilder? backgroundBuilder, WidgetBuilder? headerBuilder)
- A signature for a function that builds a blank slide.
- FlutterDeckImageSlideBuilder = Widget Function(BuildContext context, Image imageBuilder(BuildContext context), String? label, WidgetBuilder? backgroundBuilder, WidgetBuilder? headerBuilder)
- A signature for a function that builds an image slide.
- FlutterDeckPluginMenuItemBuilder = Widget Function(BuildContext context, {bool? closeOnActivate, Widget? icon, required String label, required VoidCallback? onPressed})
- A builder for menu items.
- FlutterDeckQuoteSlideBuilder = Widget Function(BuildContext context, String quote, String? attribution, int? quoteMaxLines, WidgetBuilder? backgroundBuilder, WidgetBuilder? headerBuilder)
- A signature for a function that builds a quote slide.
- FlutterDeckSlideStepsWidgetBuilder = Widget Function(BuildContext context, int stepNumber)
-
A signature for a function that builds a widget for a slide step. The
function is passed the BuildContext and the
stepNumberof the slide. - FlutterDeckSlideStepsWidgetListener = void Function(BuildContext context, int stepNumber)
-
A signature for a function that is called when the slide step changes. The
function is passed the BuildContext and the
stepNumberof the slide. - FlutterDeckSplitSlideBuilder = Widget Function(BuildContext context, WidgetBuilder leftBuilder, WidgetBuilder rightBuilder, WidgetBuilder? backgroundBuilder, WidgetBuilder? headerBuilder, SplitSlideRatio? splitRatio)
- A signature for a function that builds a split slide.
- FlutterDeckTemplateSlideBuilder = Widget Function(BuildContext context, WidgetBuilder? backgroundBuilder, WidgetBuilder? contentBuilder, WidgetBuilder? headerBuilder)
- A signature for a function that builds a template slide.
- FlutterDeckTitleSlideBuilder = Widget Function(BuildContext context, String title, String? subtitle, WidgetBuilder? backgroundBuilder, WidgetBuilder? headerBuilder, WidgetBuilder? speakerInfoBuilder)
- A signature for a function that builds a title slide.