FlutterDeckImageSlideThemeData class
Defines the visual properties of FlutterDeckImageSlide.
Used by FlutterDeckImageSlideTheme to control the visual properties of slides in a deck.
To obtain the current FlutterDeckImageSlideThemeData, use FlutterDeckImageSlideTheme.of to access the closest ancestor FlutterDeckImageSlideTheme of the current BuildContext.
See also:
- FlutterDeckImageSlideTheme, an InheritedWidget that propagates the theme down its subtree.
- FlutterDeckTheme, which describes the overall theme information for the slide deck.
Constructors
- FlutterDeckImageSlideThemeData({TextStyle? labelTextStyle})
-
Creates a theme to style
FlutterDeckImageSlide.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelTextStyle → TextStyle?
-
Text style for the image label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{TextStyle? labelTextStyle}) → FlutterDeckImageSlideThemeData - Creates a copy of this object with the given fields replaced with the new values.
-
merge(
FlutterDeckImageSlideThemeData? other) → FlutterDeckImageSlideThemeData - Merge the given FlutterDeckImageSlideThemeData with this one.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited