FlutterDeckQuoteSlideThemeData class
Defines the visual properties of FlutterDeckQuoteSlide.
Used by FlutterDeckQuoteSlideTheme to control the visual properties of slides in a deck.
To obtain the current FlutterDeckQuoteSlideThemeData, use FlutterDeckQuoteSlideTheme.of to access the closest ancestor FlutterDeckQuoteSlideTheme of the current BuildContext.
See also:
- FlutterDeckQuoteSlideTheme, an InheritedWidget that propagates the theme down its subtree.
- FlutterDeckTheme, which describes the overall theme information for the slide deck.
Constructors
- FlutterDeckQuoteSlideThemeData({TextStyle? attributionTextStyle, TextStyle? quoteTextStyle})
-
Creates a theme to style
FlutterDeckQuoteSlide.const
Properties
- attributionTextStyle → TextStyle?
-
Text style for the attribution of the quote.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- quoteTextStyle → TextStyle?
-
Text style for the quote.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{TextStyle? attributionTextStyle, TextStyle? quoteTextStyle}) → FlutterDeckQuoteSlideThemeData - Creates a copy of this object with the given fields replaced with the new values.
-
merge(
FlutterDeckQuoteSlideThemeData? other) → FlutterDeckQuoteSlideThemeData - Merge the given FlutterDeckQuoteSlideThemeData with this one.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited